<?php

if(!function_exists('get_attached_media')) {
/**
 * Retrieve media attached to the passed post.
 *
 * @since 3.6.0
 *
 * @param string      $type Mime type.
 * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
 * @return array Found attachments.
 */
 function get_attached_media( $type, $post = 0 ) {
		if ( ! $post = get_post( $post ) )
			return array();
		$args = array(
			'post_parent' => $post->ID,
			'post_type' => 'attachment',
			'post_mime_type' => $type,
			'posts_per_page' => -1,
			'orderby' => 'menu_order',
			'order' => 'ASC',
		);
		$args = apply_filters( 'get_attached_media_args', $args, $type, $post );
		$children = get_children( $args );
		return (array) apply_filters( 'get_attached_media', $children, $type, $post );
	}
}
///////////////////////////////
// Masonry Posts
///////////////////////////////
function vt_posts($query=null,$col=null,$top=20) {

	if(!$query){
		global $post;
		if($post)
			setup_postdata( $post );
	}
	if(have_posts()) :
	?>
	<div id="m-posts">
	<?php
	$i =  0;$posts =array();
	while ( have_posts() ) : the_post();
		$post_id = get_the_ID();
		$thumb = null;
		if ( ! post_password_required() && ! is_attachment() ) {
			$thumb = get_the_post_thumbnail( $post_id,'medium' );
		}
		if(!$thumb) {
			$media = get_attached_media( 'image', $post_id);
			if($media) {
				$thumb = wp_get_attachment_image(key($media),'medium');
			}
		}
		$title = get_the_title();
		$content = get_the_content();
		$url	= esc_url( get_permalink() );
		$content = ltrim(wp_trim_words ( strip_shortcodes($content),$top),'&nbsp;');
		$content = vt_remove_url_string($content);

		$key = 'right';
		if($i%2 == false) $key = 'left';
		
		$posts[$key][$i] = array(
			'post_id'		=> $post_id,
			'post_title'	=> $title,
			'post_content'	=> $content,
			'post_url'		=> $url,
			'post_thumb'	=> $thumb,
			'post_meta'		=> vt_entry_meta(false)
		);
		$i++;
	endwhile; 
	if($query == null) wp_reset_postdata();
		$count = count($posts);
		$col =  $count == 1 ? 'col-sm-12 col-xs-12 ' : 'col-sm-6 col-xs-6 ';
		$div = null;
		if($posts):
			foreach($posts as $key=>$pos):?>
			<div class="<?php echo $col . $key?>">
				<?php foreach($pos as $item):?>
				<article <?php post_class('post-entry item'); ?>>
					<a href="<?php echo $item['post_url']?>" title="<?php echo $item['post_title']?>" class="entry-a">
						<?php if($item['post_thumb']):?><span class="img-box"><?php echo $item['post_thumb']?></span><?php endif?>
						<h2><span class="title"><?php echo $item['post_title'];?></span></h2>
							<?php if($item['post_content']):?>
							<span class="post-entry-box">
								<span id="post-<?php echo $item['post_id']?>" class="entry"><?php echo $item['post_content']?></span>
							</span>
							<?php endif?>
					</a>
					<?php echo $item['post_meta'];?>
				</article>
				<?php endforeach ?>
			</div>
			<?php endforeach; ?>
		<?php endif;?>
	</div>
	<?php
	endif;
}
?>